sqltriples.Query.AbstractQuery

Package sqltriples :: Module Query :: Class AbstractQuery |
[show private | hide private]
[frames | no frames]

## Class AbstractQuery

Known Subclasses:
  `Query`, `Subject`

Method Summary
| `_get_exposed_columns(self)`

Class Variable Summary
`list` | `table_columns` = `[('subject', 'subject_type', 0), ('predi...`

Class Variable Details

    ### table_columns Type: `list` Value:
        [('subject', 'subject_type', 0),
         ('predicate', None, 0),
         ('object', 'object_type', 0)]

Generated by Epydoc 2.1 on Fri Jan 12 00:04:34 2007 | http://epydoc.sf.net